pub struct GoogleMapsPlayablelocationsV3SampleAreaFilter {
pub s2_cell_id: Option<u64>,
}Expand description
Specifies the area to search for playable locations.
This type is not used in any activity, and only used as part of another schema.
Fields
s2_cell_id: Option<u64>Required. The S2 cell ID of the area you want. This must be between cell level 11 and 14 (inclusive).
S2 cells are 64-bit integers that identify areas on the Earth. They are hierarchical, and can therefore be used for spatial indexing.
The S2 geometry library is available in a number of languages: