GoogleMapsPlayablelocationsV3SampleCriterion

Struct GoogleMapsPlayablelocationsV3SampleCriterion 

pub struct GoogleMapsPlayablelocationsV3SampleCriterion {
    pub fields_to_return: Option<FieldMask>,
    pub filter: Option<GoogleMapsPlayablelocationsV3SampleFilter>,
    pub game_object_type: Option<i32>,
}
Encapsulates a filter criterion for searching for a set of playable locations.

This type is not used in any activity, and only used as part of another schema.

Fields

fields_to_return: Option<FieldMask>

Specifies which PlayableLocation fields are returned.

name (which is used for logging impressions), center_point and place_id (or plus_code) are always returned.

The following fields are omitted unless you specify them here:

  • snapped_point
  • types

Note: The more fields you include, the more expensive in terms of data and associated latency your query will be.

filter: Option<GoogleMapsPlayablelocationsV3SampleFilter>

Specifies filtering options, and specifies what will be included in the result set.

game_object_type: Option<i32>

Required. An arbitrary, developer-defined identifier of the type of game object that the playable location is used for. This field allows you to specify criteria per game object type when searching for playable locations.

You should assign a unique game_object_type ID across all request_criteria to represent a distinct type of game object. For example, 1=monster location, 2=powerup location.

The response contains a map<game_object_type, Response>.