pub struct GoogleMapsUnityClientInfo {
pub api_client: Option<String>,
pub application_id: Option<String>,
pub application_version: Option<String>,
pub device_model: Option<String>,
pub language_code: Option<String>,
pub operating_system: Option<String>,
pub operating_system_build: Option<String>,
pub platform: Option<String>,
}Expand description
Client information.
This type is not used in any activity, and only used as part of another schema.
Fields
api_client: Option<String>API client name and version. For example, the SDK calling the API. The exact format is up to the client.
application_id: Option<String>Application ID, such as the package name on Android and the bundle identifier on iOS platforms.
application_version: Option<String>Application version number, such as “1.2.3”. The exact format is application-dependent.
device_model: Option<String>Device model as reported by the device. The exact format is platform-dependent.
language_code: Option<String>Language code (in BCP-47 format) indicating the UI language of the client. Examples are “en”, “en-US” or “ja-Latn”. For more information, see http://www.unicode.org/reports/tr35/#Unicode_locale_identifier.
operating_system: Option<String>Operating system name and version as reported by the OS. For example, “Mac OS X 10.10.4”. The exact format is platform-dependent.
operating_system_build: Option<String>Build number/version of the operating system. e.g., the contents of android.os.Build.ID in Android, or the contents of sysctl “kern.osversion” in iOS.
platform: Option<String>Platform where the application is running.