pub struct MethodMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all free methods, which are not associated with a particular resource.
It is not used directly, but through the PlayableLocations hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_playablelocations3 as playablelocations3;
use playablelocations3::{PlayableLocations, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = PlayableLocations::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `log_impressions(...)`, `log_player_reports(...)` and `sample_playable_locations(...)`
// to build up your call.
let rb = hub.methods();Implementations
Sourceimpl<'a, C> MethodMethods<'a, C>
impl<'a, C> MethodMethods<'a, C>
Sourcepub fn log_impressions(
&self,
request: GoogleMapsPlayablelocationsV3LogImpressionsRequest,
) -> MethodLogImpressionCall<'a, C>
pub fn log_impressions( &self, request: GoogleMapsPlayablelocationsV3LogImpressionsRequest, ) -> MethodLogImpressionCall<'a, C>
Create a builder to help you perform the following task:
Logs new events when playable locations are displayed, and when they are interacted with.
Impressions are not partially saved; either all impressions are saved and this request succeeds, or no impressions are saved, and this request fails.
Arguments
request- No description provided.
Sourcepub fn log_player_reports(
&self,
request: GoogleMapsPlayablelocationsV3LogPlayerReportsRequest,
) -> MethodLogPlayerReportCall<'a, C>
pub fn log_player_reports( &self, request: GoogleMapsPlayablelocationsV3LogPlayerReportsRequest, ) -> MethodLogPlayerReportCall<'a, C>
Create a builder to help you perform the following task:
Logs bad playable location reports submitted by players.
Reports are not partially saved; either all reports are saved and this request succeeds, or no reports are saved, and this request fails.
Arguments
request- No description provided.
Sourcepub fn sample_playable_locations(
&self,
request: GoogleMapsPlayablelocationsV3SamplePlayableLocationsRequest,
) -> MethodSamplePlayableLocationCall<'a, C>
pub fn sample_playable_locations( &self, request: GoogleMapsPlayablelocationsV3SamplePlayableLocationsRequest, ) -> MethodSamplePlayableLocationCall<'a, C>
Create a builder to help you perform the following task:
Returns a set of playable locations that lie within a specified area, that satisfy optional filter criteria.
Note: Identical SamplePlayableLocations requests can return different
results as the state of the world changes over time.
Arguments
request- No description provided.