pub struct GoogleMapsPlayablelocationsV3SampleFilter {
pub included_types: Option<Vec<String>>,
pub max_location_count: Option<i32>,
pub spacing: Option<GoogleMapsPlayablelocationsV3SampleSpacingOptions>,
}Expand description
Specifies the filters to use when searching for playable locations.
This type is not used in any activity, and only used as part of another schema.
Fields
included_types: Option<Vec<String>>Restricts the set of playable locations to just the types that you want.
max_location_count: Option<i32>Specifies the maximum number of playable locations to return. This value must not be greater than 1000. The default value is 100.
Only the top-ranking playable locations are returned.
spacing: Option<GoogleMapsPlayablelocationsV3SampleSpacingOptions>A set of options that control the spacing between playable locations. By default the minimum distance between locations is 200m.